@@ -5,7 +5,7 @@ from typing import Awaitable, BinaryIO, Callable, Dict, List, Optional, Tuple, U
 import aiohttp
 from karas.util import DefaultNamespace, status_code_exception
 from karas.util.sync import async_to_sync_wrap
-from karas.chain import MessageChain
+from karas.chain import Forward, MessageChain, node
 from karas.Sender import Friend, Group, Member, Stranger, ReceptorBase, Announcement
 from karas.messages import MessageBase
 from karas.event import Auto_Switch_Event, EventBase, MemberJoinRequestEvent, NewFriendRequestEvent, RequestEvent, Event, NudgeEvent
@@ -16,7 +16,7 @@ from karas.util.Logger import Logging
 from karas.util.network import error_throw, URL_Route, wrap_data_json
 
 
-__version__ = "0.1.8"
+__version__ = "0.2.0"
 
 
 async def _build_content_json(
@@ -59,9 +59,10 @@ class Karas(object):
 
     @classmethod
     async def _executor(cls, message: Union["MessageBase", "EventBase"] = None) -> Optional[str]:
-        if cls.listeners.get(message.type) is None:
+        events = cls.listeners.get(message.type)
+        if events is None:
             return
-        for listener in cls.listeners.get(message.type):
+        for listener in events:
             ca, cb, cb_args = listener
             if cb:
                 cb_args = cb_args or ()
@@ -173,6 +174,8 @@ class Yurine(object):
             await self._connect()
             self.logging.info("Account verify success")
             self.logging.debug(f"got verifyKey {self.sessionKey}")
+        self.logging.info("connect success")
+        self.logging.info("++++++++++++++++++++++++++++++++++++++++")
         return 0
 
     @error_throw
@@ -233,12 +236,12 @@ class Yurine(object):
         return 0
 
     @error_throw
-    async def _receiver(self) -> None:
+    async def _receiver(self, data: Dict = None) -> None:
         """事件监听器"""
         self._receiver_is_running = True
         while True:
             try:
-                _receive_data: Dict = await self.ws.receive_json()
+                _receive_data: Dict = data or await self.ws.receive_json()
             except (BotBaseException, TypeError):
                 pass
             except Exception:
@@ -255,6 +258,9 @@ class Yurine(object):
                 self._receivData[syncId] = _receive_data
             else:
                 self.logging.debug(f"Unknown event:{_receive_data}")
+            if data:
+                self.logging.debug(f"got other data {data}")
+                break
 
     def listen(self, registerEvent: Union[str, "EventBase", "MessageBase"], callback: Callable = None, cb_args: Optional[Tuple] = None):
         """事件装饰器
@@ -452,9 +458,15 @@ class Yurine(object):
     async def _element_check(self, element: "ElementBase", type: str, target: Union[int, Group, None] = None):
         if isinstance(element, (Image, Voice, FlashImage)):
             await self.uploadMultipart(element, type=type)
+        if isinstance(element, Forward):
+            nodeList = element.nodeList
+            if nodeList:
+                element.nodeList = [await self._element_check(node,type=type) for node in nodeList]
+        if isinstance(element, node):
+            element.messageChain = [await self._element_check(e,type=type) for e in element.messageChain._get_elements()]
         if isinstance(element, File):
             raise FunctionException("文件上传请使用uploadFile方法，该方法仅支持发送消息")
-        return element.elements
+        return element.elements if isinstance(element,ElementBase) else element
 
     @error_throw
     async def about(self):
@@ -497,7 +509,7 @@ class Yurine(object):
                 command="sendGroupMessage",
                 content=content
             ))
-        self.logging.info(f"bot <= {MessageChain(*_chain).to_str()}")
+        self.logging.info(f"Group({group.name if isinstance(group,Group) else group}) <= {MessageChain(*_chain).to_str()}")
         echo = await self._raise_status(syncId=syncId)
         return echo.get("messageId")
 
@@ -531,7 +543,7 @@ class Yurine(object):
                 content=content
             )
         )
-        self.logging.info(f"Bot <= {MessageChain(*_chain).to_str()}")
+        self.logging.info(f"Friend:{friend.nickname if isinstance(friend, Friend) else friend} <= {MessageChain(*_chain).__str__()}")
         echo = await self._raise_status(syncId=syncId)
         return echo.get("messageId")
 
@@ -572,7 +584,7 @@ class Yurine(object):
                 content=content
             )
         )
-        self.logging.info(f"bot <= {MessageChain(*_chain).to_str()}")
+        self.logging.info(f"Temp{member.memberName if isinstance(member, Member) else member} <= {MessageChain(*_chain).to_str()}")
         echo = await self._raise_status(syncId=syncId)
         return echo.get("messageId")
 
@@ -583,15 +595,19 @@ class Yurine(object):
         Args:
             message (Union[Source, int]): 要撤回的消息，可以是一个Source或者消息Id
         """
+        syncId = self.namespace.gen()
         await self.ws.send_json(
             wrap_data_json(
                 command="recall",
-                syncId="recall",
+                syncId=syncId,
                 content={
                     "messageId": message.id if isinstance(message, Source) else message
                 }
             )
         )
+        self.logging.info(f"BotRecall: {message.id if isinstance(message,Source) else message}")
+        echo = await self._raise_status(syncId=syncId)
+        return echo.get("msg")
 
     @error_throw
     async def sendNudge(
@@ -630,8 +646,8 @@ class Yurine(object):
                     "kind": kind
                 }))
         self.logging.info(f"Bot <= NudgeEvent:{subject}")
-        data = await self._raise_status(syncId=syncId)
-        return data
+        echo = await self._raise_status(syncId=syncId)
+        return echo.get("msg")
 
     @error_throw
     async def fetchMessageFromId(
@@ -1489,8 +1505,13 @@ class Yurine(object):
 
     async def _raise_status(self, data: Optional[Dict] = None, syncId: str = None) -> Dict:
         try:
-            await asyncio.sleep(.1)
-            _json_data = data or (syncId and self._receivData.get(syncId)) or await self.ws.receive_json()
+            while 1:
+                await asyncio.sleep(.1)
+                _json_data = data or (syncId and self._receivData.pop(syncId,None)) or await self.ws.receive_json()
+                if _json_data.get("syncId") and _json_data.get("syncId") == "-1":
+                    await self._receiver(_json_data)
+                    continue
+                break
         except RuntimeError:
             return await self._raise_status(data=data, syncId=syncId)
         self.logging.debug(f"recv data {_json_data}")
