@@ -1,8 +1,6 @@
 from enum import Enum
 from typing import Any, BinaryIO, Dict, Optional, Union
-
 from karas.permission import Permission
-
 from karas.util import BaseModel
 
 
@@ -11,10 +9,10 @@ class ElementBase(BaseModel):
 
     @property
     def elements(self) -> Dict[Any, Any]:
-        return {_K: _V for _K, _V in self.__dict__.items() if _V is not None}
+        return {_K: _V for _K, _V in self.__dict__.items() if _V is not None and not _K.startswith("_")}
 
     def __str__(self) -> str:
-        return f"{self.type}:{[str(_v) for _v in self.__dict__.values()]}"
+        return f" [{self.type}] "
 
 
 class At(ElementBase):
