@@ -1,9 +1,7 @@
 from enum import Enum
-from typing import Optional, Union
+from typing import Union
 from karas.chain import MessageChain
-
 from karas.util import BaseModel
-
 from karas.Sender import Client, Friend, Group, Member, Operator, Stranger, Subject
 from karas.messages import MessageBase, MessageEnum
 from karas.permission import Permission
@@ -166,7 +164,7 @@ class BotJoinGroupEvent(GroupEventBase):
     """Bot加入了一个新群"""
     type: str = "BotJoinGroupEvent"
     group: Group
-    invitor: Optional[Member]
+    invitor: Member
 
     def __str__(self) -> str:
         return super().__str__() + f":{self.group}"
@@ -184,7 +182,7 @@ class BotLeaveEventActive(GroupEventBase):
 class BotLeaveEventKick(GroupEventBase):
     """Bot被踢出一个群"""
     type: str = "BotLeaveEventKick"
-    operator: Optional[Member]
+    operator: Member
 
     def __str__(self) -> str:
         return super().__str__() + f":{self.group}"
@@ -377,8 +375,7 @@ class MemberMuteEvent(GroupEventBase):
 
 class MemberUnmuteEvent(GroupEventBase):
     """群成员被取消禁言事件（该成员不是Bot）"""
-    type: str = "MemberMuteEvent"
-    durationSeconds: int
+    type: str = "MemberUnmuteEvent"
     member: Member
     operator: Operator
 
@@ -463,8 +460,8 @@ class CommandExecutedEvent(EventBase):
     """命令被执行"""
     type: str = "CommandExecutedEvent"
     name: str
-    friend: Optional[Friend]
-    member: Optional[Member]
+    friend: Friend
+    member: Member
     args: dict
 
 
